package com.inspect.taskinfo.service;


import com.inspect.taskinfo.domain.PatrolTaskInfo;

import java.util.List;
import java.util.Map;

public interface IPatrolTaskInfoService {
    PatrolTaskInfo selectPatrolTaskInfoByLineId(Long lineId);

    PatrolTaskInfo selectTaskInfoByBaseId(String baseId);
    List<PatrolTaskInfo> selectTaskInfoByBaseIds(List<String> baseIds);

    String selectAlgSubtypeIdsByPatrolPointId(String patrolPointId);

    Map<String, String> selectVideoPosByPointId(String pointId);

    List<Map<String, String>> selectVideoPosByPointIdByEqpbookIds(List<String> pointIds);

    Map<String, String> selectPoseInfo(String key, String key2);

    List<PatrolTaskInfo> selectPatrolTaskInfoList(PatrolTaskInfo info);

    Map<String, List> selectPatrolTaskInfoListByMajorId(String majorId);

    List<PatrolTaskInfo> selectPatrolTask(PatrolTaskInfo patrolTaskInfo);

    List<PatrolTaskInfo> selectPatrolAbnormalTaskList(PatrolTaskInfo patrolTaskInfo);

    int insertPatrolTaskInfo(PatrolTaskInfo patrolTaskInfo);

    int batchInsertPatrolTaskInfo(List<PatrolTaskInfo> patrolTaskInfo);

    int updatePatrolTaskInfo(PatrolTaskInfo patrolTaskInfo);

    int deletePatrolTaskInfoByLineIds(Long[] lineIds);

    int deletePatrolTaskInfoByLineId(Long lineId);

    int deletePatrolTaskInfoByMajorIds(Long[] majorIds);

    List<Map<String, Object>> selectPatrolTaskInfoCount(List<String> taskInfoIds);

    int deletePatrolTaskInfoByMajorId(Long majorId);

    int countPatrolTaskInfoByMajorId(String taskMajorId);
}
